@@ -1,16 +1,21 @@
 """
 Utils for creating a JSON RPC connection to an EVM blockchain
 """
+import logging
 from dataclasses import dataclass
 from dataclasses import field
 from typing import List
 from typing import Optional
 
+import websockets.exceptions
+from web3 import Web3
+from web3.middleware import geth_poa_middleware
+
 from telliot_core.apps.config import ConfigFile
 from telliot_core.apps.config import ConfigOptions
 from telliot_core.model.base import Base
-from web3 import Web3
-from web3.middleware import geth_poa_middleware
+
+logger = logging.getLogger(__name__)
 
 
 @dataclass
@@ -39,6 +44,9 @@ class RPCEndpoint(Base):
     def connect(self) -> bool:
         """Connect to EVM blockchain
 
+        A connection failure does not raise an exception.  This is left
+        to the caller.
+
         returns:
             True if connection was successful
         """
@@ -53,22 +61,22 @@ class RPCEndpoint(Base):
         else:
             raise ValueError(f"Invalid endpoint url: {self.url}")
 
-        # Inject middlware if connecting to rinkeby
-        try:
-            if self.network == "rinkeby":
-                self.web3.middleware_onion.inject(geth_poa_middleware, layer=0)
-        except Exception:
-            print("unable to connect to rinkeby")
+        # Inject middleware if connecting to rinkeby (chain_id=4)
+        if self.chain_id == 4:
+            self.web3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
+        connected = False
         try:
-            connected = self._web3.isConnected()
-        # Pokt nodes won't submit isConnected rpc call
-        except Exception:
             connected = self._web3.eth.get_block_number() > 1
-        if connected:
-            print("Connected to {}".format(self))
-        else:
-            print("Could not connect to {}".format(self))
+            logger.debug("Connected to {}".format(self))
+
+        except websockets.exceptions.InvalidStatusCode as e:
+            connected = False
+            msg = f"Could not connect to RPC endpoint at: {self.url}"
+            logger.error(e)
+            logger.error(msg)
+            print(e)
+            print(msg)
 
         return connected
 
